Widgets - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## Widgets

### Food Deliver UI dashboards

Updated 2 hours ago
25%
25% Complete

### Projects Dashboards

Updated 2 hours ago
76%
76% Complete
Maryjo Lebarree
Civil Engineer
EP
Egan Poetz
Research Nurse
Kellie Skingley
Teacher
Christabel Charlwood
Tax Accountant
Thatcher Keel
VP Sales
View full profile
Dyann Escala
Mechanical Systems Engineer
View full profile
Avivah Mugleston
Actuary
View full profile
AA
Arlie Armstead
VP Quality Control
View full profile
Marsha Labat
Research Associate
Elston Muffett
Account Coordinator
Leigha Gorce
Geologist II
TB
Tallie Bettis
Director of Sales

#### Paweł Kuna

Working in Tabler
Online
Subscribe

#### Mallory Hulme

Working in Kare
Online
Subscribe
132 Sales
12 waiting payments
78 Orders
32 shipped
1352 Members
163 registered today
132 Comments
16 waitings
132 Sales
12 waiting payments
78 Orders
32 shipped
1352 Members
163 registered today
132 Comments
16 waitings
$5,256.99 +4%
Revenue last 30 days
342 -4.3%
Sales last 30 days
132 +6.8%
Customers last 30 days
78 -2%
Members registered today
1700
Users
1700
Users
1700
Users
HS
1700
Users
1700
Users
1700
Users
1700
Users
1700
Users

### Card with code

    .card-footer {
    	background: transparent;

    	&:last-child {
    		border-radius: 0 0 1 2;
    	}
    }

W

### New website

Due to: 28 Aug 2019

Waiting

JL
38% Complete
20% Complete

### Tabler UI v1.0

JL
5/10
Due 72 days
20% Complete

### Tabler React

5/10
Due 2 days
Basic info
Went to: University of Ljubljana
Worked at: Devpulse
Lives in: Šentilj v Slov. Goricah, Slovenia
From: Slovenia
Birth date: 13/01/1985
Time zone: Europe/Ljubljana

### Configuration

Edit configuration

Date:
  2020-01-05 16:42:29 UTC
Account:
  tabler
Location:
  Poland
IP Address:
  46.113.11.3
Operating system:
  OS X 10.15.2 64-bit
Browser:
  Chrome